sequencetools.partition_sequence_by_backgrounded_weights
========================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_by_backgrounded_weights.partition_sequence_by_backgrounded_weights
